@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# $Id: wikiup.py,v 1.37 2005/09/01 04:53:45 villate Exp $
+# $Id: wikiup.py,v 1.38 2005/09/02 14:39:36 villate Exp $
 
 """ Wikiup utility functions.
 """
@@ -124,7 +124,7 @@ def LatexToPNG(equation, file , resolution=72):
     texfile.close()
     dviname = texname.replace('.tex','.dvi')
     logname = texname.replace('.tex','.log')
-    os.system('dvipng -o %s -D%s -z9 -truecolor 1 -T tight %s 1>%s' % (file, resolution, dviname, devNull()))
+    os.system('dvipng -o %s -D%s -z9 --truecolor -T tight %s 1>%s' % (file, resolution, dviname, devNull()))
     removeFile(dviname)
     removeFile(logname)
     return
@@ -322,7 +322,8 @@ class WikiTranslator:
 
             # processes the previous line
             text = self.parseLine(previous)
-            if text: text += '\n'
+            if (text or self.Code == 'pre'):
+                text += '\n'
             self.htmlPageText.append(text)
             previous = line
 
@@ -337,28 +338,29 @@ class WikiTranslator:
 
     def parseLine(self, line):
 
-        # blank line
-        if ((not line or line.isspace()) and self.Code != 'pre'):
-            self.Code = '...'
-            self.TblStyle = ''
-            self.TblColcount = 0
-            if self.Depth > 0:
-                return self.Estk.emitCode(self.Code, self.Depth-1)
-            else:
-                return ''
-            
-        # Parse escaped dollar signs
         if self.Code != 'pre':
+            
+            # blank lines
+            if (not line or line.isspace()):
+                self.Code = '...'
+                self.TblStyle = ''
+                self.TblColcount = 0
+                if self.Depth > 0:
+                    return self.Estk.emitCode(self.Code, self.Depth-1)
+                else:
+                    return ''
+            
+            # protect escaped dollar signs
             line = self.escdollarExpr.sub(self.encodeEscapedText, line)
             line.replace('        ','\t')
         
-        # Equations
-        line = self.mathExpr.sub(self.substituteMath, line)
+            # equations
+            line = self.mathExpr.sub(self.substituteMath, line)
 
-        # Parse special characters
-        if self.Code != 'pre':
+            # protect escaped characters
             line = self.escapeExpr.sub(self.encodeEscapedText, line)
         
+        # parse special HTML characters
         line = line.replace('&','&amp;')
         line = line.replace('<','&lt;')
         line = line.replace('>','&gt;')
